==> haskell-abstract-deque-0.3-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-abstract-deque.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: abstract-deque
version: 0.3
id: abstract-deque-0.3-GrgiPXB2fbbKYfNSIYfZyO
key: abstract-deque-0.3-GrgiPXB2fbbKYfNSIYfZyO
license: BSD3
maintainer: rrnewton@gmail.com
homepage: https://github.com/rrnewton/haskell-lockfree/wiki
synopsis: Abstract, parameterized interface to mutable Deques.
description:
    An abstract interface to highly-parameterizable queues/deques.
    .
    Background: There exists a feature space for queues that extends between:
    .
    * simple, single-ended, non-concurrent, bounded queues
    .
    * double-ended, threadsafe, growable queues
    .
    ... with important points inbetween (such as
    the queues used for work-stealing).
    .
    This package includes an interface for Deques that allows the
    programmer to use a single API for all of the above, while using the
    type-system to select an efficient implementation given the
    requirements (using type families).
    .
    This package also includes a simple reference implementation based
    on '\''IORef'\'' and "Data.Sequence".
category: Data
author: Ryan R. Newton
exposed: True
indefinite: False
exposed-modules:
    Data.Concurrent.Deque.Class Data.Concurrent.Deque.Debugger
    Data.Concurrent.Deque.Reference
    Data.Concurrent.Deque.Reference.DequeInstance
abi: 008a81f130e66b891a38a1dad3a0ddd0
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/abstract-deque-0.3
library-dirs: /usr/lib/ghc-8.2.1/site-local/abstract-deque-0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/abstract-deque-0.3
hs-libraries: HSabstract-deque-0.3-GrgiPXB2fbbKYfNSIYfZyO
depends:
    base-4.10.0.0 array-0.5.2.0 random-1.1-DtLcP2Z2iOOC0RwcSmXjBK
    containers-0.5.10.2 time-1.8.0.2
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             array-0.5.2.0=5abf025fb7bf60079ec1f42bab285152
             random-1.1-DtLcP2Z2iOOC0RwcSmXjBK=4de0c0628e95d26e613f423e1634f42a
             containers-0.5.10.2=e086202b65ca66a107fcba9d846fc3e0
             time-1.8.0.2=3f789f9c9fc88790a10579b55c2f0b4f
haddock-interfaces: /usr/share/doc/haskell-abstract-deque/html/abstract-deque.haddock
haddock-html: /usr/share/doc/haskell-abstract-deque/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-abstract-deque-0.3-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-abstract-deque.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: abstract-deque
version: 0.3
id: abstract-deque-0.3-2koRGk0qTMQE4aX1mMpi3R
key: abstract-deque-0.3-2koRGk0qTMQE4aX1mMpi3R
license: BSD3
maintainer: rrnewton@gmail.com
homepage: https://github.com/rrnewton/haskell-lockfree/wiki
synopsis: Abstract, parameterized interface to mutable Deques.
description:
    An abstract interface to highly-parameterizable queues/deques.
    .
    Background: There exists a feature space for queues that extends between:
    .
    * simple, single-ended, non-concurrent, bounded queues
    .
    * double-ended, threadsafe, growable queues
    .
    ... with important points inbetween (such as
    the queues used for work-stealing).
    .
    This package includes an interface for Deques that allows the
    programmer to use a single API for all of the above, while using the
    type-system to select an efficient implementation given the
    requirements (using type families).
    .
    This package also includes a simple reference implementation based
    on '\''IORef'\'' and "Data.Sequence".
category: Data
author: Ryan R. Newton
exposed: True
indefinite: False
exposed-modules:
    Data.Concurrent.Deque.Class Data.Concurrent.Deque.Debugger
    Data.Concurrent.Deque.Reference
    Data.Concurrent.Deque.Reference.DequeInstance
abi: bb7f56e761a133974edc0be289658ed9
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/abstract-deque-0.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/abstract-deque-0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/abstract-deque-0.3
hs-libraries: HSabstract-deque-0.3-2koRGk0qTMQE4aX1mMpi3R
depends:
    base-4.10.1.0 array-0.5.2.0 random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We
    containers-0.5.10.2 time-1.8.0.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We=368a9f817c8c1b290191231dd0d81d85
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
haddock-interfaces: /usr/share/doc/haskell-abstract-deque/html/abstract-deque.haddock
haddock-html: /usr/share/doc/haskell-abstract-deque/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
